<?php

class BaseTest extends PHPUnit\Framework\TestCase {
}

class AIndirectExtendTest extends BaseTest {
}

class BIndirectExtendTest extends BaseTest {
}

